@@ -14,14 +14,22 @@ class Pp
 	int ntypes;
 	int tor;
 	int *toroidal;
-
+	double windowArea;
 
 	double (Pp::*dist)(int*, int*);
+	double (Pp::*weight)(int*, int*);
 	double distEuclidian(int*, int*);
 	double distPrecalculated(int*, int*);
+	double edgeDist(int *);
+	double edgeDistPrecalculated(int *);
+	double (Pp::*edgeDistp)(int *);
+	double weightAll1(int *, int *);
+	double weightTrans(int *, int *);
 	std::vector<double> distTriangle;
+	std::vector<double> weightTriangle;
 	std::vector<double> * pdists;
 	std::vector<int> typevec;
+	std::vector<double> distEdge;
 
 public:
 	std::vector<double > lambdas;
@@ -49,16 +57,25 @@ public:
 
 	double getDist(int *, int *);
 	void   calcDists();
+	void   setDist(int *, int *, double d);
 	void   setDists(double *);
+	double getEdgeDist(int *);
+	void   calcEdgeDists();
+
+	double getWeight(int *, int *);
+	void   setWeight(int *, int *, double d);
+	void   calcTransWeights();
+	void   setAllTransWeights(double );
 
 	int    getCluster(int *);
 	int    nsize(int*); // neighbours
-	void   setMass(int *, double );
+	void   setMass(int *, double *);
 	double getMass(int *);
-	void   setMass2(int *, double );
+	void   setMass2(int *, double *);
 	double getMass2(int *);
 
 	int Empty(int *, int *, int *); //voronoi
+	int EmptyConstrained(int *, int *, int *, std::vector <int>  *);
 
 	void addNeighbour(int *i, int *j);
 	void removeNeighbour(int *i, int *j);
